************************
Contributors and Credits
************************

A number of current and former members of the Condensed Matter Physics Group
at the University of Leeds have contributed to this code in various forms.

The original versions were developed by Dr Matthew Newman and Dr Chris Allen.
Dr Rowan Temple, Dr Sophie Morely and Dr Joe Batley have all contributed file formats,
plot styles. They, and Dr May Wheeler, Dr Philippa Shepley and Nathan Satchell have 
found bugs and made helpful suggestions.

The lead developer is Dr Gavin Burnell <g.burnell@leeds.ac.uk>. Most of the
development of this code has been indirectly supported by the UK Engineering
and Physical Sciences Research Council.

The code, except where otherwise noted, is Copyrigt The University of Leeds 
2008-2016 and is released under the GNU Public License v3.